package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(J``````````0```````
M`+&0``````!``#@`"0!``!H`&0````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*:0````````II``
M```````0``````$````&````````J\@```````"[R````````+O(````````
M!,`````````$Z````````!```````@````8```````"KV````````+O8````
M````N]@````````"``````````(```````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````GW````````"?<````````)]P`````````.P`````````[```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*O(````````N\@`````
M``"[R`````````0X````````!#@``````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4`?PNLF1[C835Q,-M`SXEM<F(A,:(````$````$```
M``%'3E4```````````,````"```````````````1````0P````0````(A`1`
M!0`0$""$`(:`!``"*`@$(`D"`(F""`(`ND$0@(@`````````0P```$8```!)
M````2@```%(```!3````5`````````!6````5P```%@```!9````6@```%P`
M`````````!_?Q6XM1][.?)I_:[:;Q2Y\U&34#N3_(1Q8<=D!QD?B;XL!LL#C
M2ZR'U_I"+#_EPGR2X[I@;*'ZF\-/F=9#"6MFS*]G[-5%0M-P!XGMVV(SS"6,
M%0N7.@V;G*E_"@*GX%">&FM)^^"C````````````````````````````````
M```````````#```+````````&/@``````````````V@2````````````````
M`````````````.02`````````````````````````````K01````````````
M`````````````````H02`````````````````````````````)82````````
M`````````````````````5T2`````````````````````````````;42````
M`````````````````````````/H2`````````````````````````````>X2
M``````````````````````````````$@````````````````````````````
M`702`````````````````````````````KP2````````````````````````
M`````9P2`````````````````````````````>,2````````````````````
M`````````2L2`````````````````````````````=P2````````````````
M`````````````1L2`````````````````````````````0T2````````````
M`````````````````=02`````````````````````````````JH2````````
M`````````````````````!`@`````````````````````````````7L2````
M`````````````````````````A$2`````````````````````````````K(1
M`````````````````````````````E\2````````````````````````````
M`"P@`````````````````````````````C\2````````````````````````
M`````$82`````````````````````````````AH2````````````````````
M`````````&,6`````````````````````````````4T2````````````````
M`````````````:X2`````````````````````````````'82````````````
M`````````````````-,2`````````````````````````````(<2````````
M`````````````````````:02`````````````````````````````F8B````
M`````````````````````````ID2`````````````````````````````9<2
M`````````````````````````````+<2````````````````````````````
M`?42`````````````````````````````@H2````````````````````````
M`````?L2`````````````````````````````3\2````````````````````
M`````````.X2`````````````````````````````882````````````````
M`````````````G42`````````````````````````````C`2````````````
M`````````````````CX2`````````````````````````````<T2````````
M`````````````````````*(2`````````````````````````````>D2````
M`````````````````````````6@2`````````````````````````````.D2
M`````````````````````````````;X2````````````````````````````
M`,81`````````````````````````````<42````````````````````````
M`````HL2`````````````````````````````B(2````````````````````
M`````````302`````````````````````````````GP2````````````````
M`````````````%02`````````````````````````````D82````````````
M`````````````````I(2`````````````````````````````E@1````````
M`````````````````````W$2```-````````0F``````````V@```\82```-
M````````.8`````````&F````E,2```-````````(!@````````"B````N@2
M```-````````*X@`````````!@```P82```-````````0!@````````"1```
M`^P2```-````````*Y`````````"7````ZP0```7````````P(@`````````
M`````OD2```-````````+?``````````-@```QP2```-````````-5``````
M````>````WT1```/````````7N``````````!````YD2```-````````6F@`
M```````!R@```Z02```-````````*G@`````````.````\$0```7````````
MP+```````````````]H2```-````````.'`````````!"@``!`,2```-````
M````-<@`````````>````XP0```6````````P````````````````T`2```-
M````````+B@````````!2````],0```6````````P(@``````````````_D1
M```6````````P(``````````"````Y(2```-````````(J``````````````
M`[@2```-````````6?@`````````;````XX@```6````````P```````````
M`````U82```-````````.$``````````+@```RH2```-````````*K``````
M````U````TP2```-````````7#@````````":```!`L2```-````````+W``
M```````%W`!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M
M`%!E<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L7V%T9F]R
M:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?
M;F]C;VYT97AT`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE
M=UA37V9L86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U
M;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`
M4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P97)L
M7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%]?<W1A8VM?
M8VAK7V9A:6P`97AI=`!L<V5E:S8T`')E861D:7(V-`!S=')D=7``8VQO<V5D
M:7(`;W!E;C8T`'-T<G)C:'(`=6YL:6YK`&UE;6UO=F4`<W1R=&]K`')M9&ER
M`')E860`<W1R<W1R`&UK9&ER`%]?=F9P<FEN=&9?8VAK`&=E='!I9`!R96%D
M;&EN:P!R96%L;&]C`%]?<W!R:6YT9E]C:&L`7U]F<')I;G1F7V-H:P!L<W1A
M=#8T`%]?;&EB8U]S=&%R=%]M86EN`'-T9&5R<@!M96UC:'(`7U]C>&%?9FEN
M86QI>F4`<W1R8VAR`&]P96YD:7(`9V5T=6ED`&%C8V5S<P!M96UC<'D`7U]E
M<G)N;U]L;V-A=&EO;@!S=')N8VUP`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T
M9F]R:P!L:6)P97)L+G-O+C4N,S8`;&EB8RYS;RXV`'!A<E]C=7)R96YT7V5X
M96,`<&%R7V)A<V5N86UE`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV
M7V-L96%N`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!S:&%?
M9FEN86P`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``
M7TE/7W-T9&EN7W5S960`7U]D871A7W-T87)T`'-H85]U<&1A=&4`>'-?:6YI
M=`!?7V)S<U]S=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M<&1I<@!?961A
M=&$`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P
M87)?9&EE`'!A<E]I;FET7V5N=@!'3$E"0U\R+C,T`$=,24)#7S(N-`!'3$E"
M0U\R+C,S`$=,24)#7S(N,RXR`$=,24)#7S(N,@````````(``0`"``(``0`!
M``(``0`"``$``@`#``(``@`!``(``0`!``(``@`!``$``@`"``(``0`$``$`
M`@`!``$``@`!``$``0`"``(``@`"``$``@`"``4``0`!``4``@`%``0``@`!
M``(``0`"``(``0`"``(`!0`!``(``0`&``(``@`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`%```"W@``
M`!``````!I:1M`````8```08````$`UI:10````%```$(P```!`&EI&S````
M!```!"T````0"6D9<@````,```0X````$`UI:1(````"```$1```````````
M``"[R``````````,````````(Y````````"[T``````````,````````(T@`
M``````"_^``````````,````````(!@```````#`"``````````,````````
MP`@```````#`(``````````,````````8>````````#`*``````````,````
M````7SP```````#`.``````````,````````7]P```````#`0``````````,
M````````7^````````#`2``````````,````````8=0```````#`4```````
M```,````````7T(```````#`6``````````,````````8=P```````#`:```
M```````,````````8<0```````#`<``````````,````````8<H```````#`
M@``````````,````````8>8```````"_H`````0````*````````````````
M``"_J`````D````*``````````````````"_L`````L````*````````````
M``````"_N````!8````*``````````````````"_P````!L````*````````
M``````````"_R````!\````X``````````````````"_T````"`````*````
M``````````````"_V````"(````*``````````````````"_X````"8````*
M``````````````````"_Z````#D````*``````````````````"_\````$(`
M```*``````````````````"]\`````(````+``````````````````"]^```
M``,````+``````````````````"^``````4````+``````````````````"^
M"`````8````+``````````````````"^$`````<````+````````````````
M``"^&`````@````+``````````````````"^(`````H````+````````````
M``````"^*`````P````+``````````````````"^,`````T````+````````
M``````````"^.`````X````+``````````````````"^0`````\````+````
M``````````````"^2````!`````+``````````````````"^4````!$````+
M``````````````````"^6````!(````+``````````````````"^8````!,`
M```+``````````````````"^:````!0````+``````````````````"^<```
M`!4````+``````````````````"^>````!<````+``````````````````"^
M@````!@````+``````````````````"^B````!H````+````````````````
M``"^D````!P````+``````````````````"^F````!T````+````````````
M``````"^H````!X````+``````````````````"^J````"$````+````````
M``````````"^L````",````+``````````````````"^N````"0````+````
M``````````````"^P````"4````+``````````````````"^R````"8````+
M``````````````````"^T````"<````+``````````````````"^V````"@`
M```+``````````````````"^X````"D````+``````````````````"^Z```
M`"H````+``````````````````"^\````"L````+``````````````````"^
M^````"P````+``````````````````"_`````"T````+````````````````
M``"_"````"X````+``````````````````"_$````"\````+````````````
M``````"_&````#`````+``````````````````"_(````#$````+````````
M``````````"_*````#(````+``````````````````"_,````#,````+````
M``````````````"_.````#0````+``````````````````"_0````#4````+
M``````````````````"_2````#8````+``````````````````"_4````#<`
M```+``````````````````"_6````#@````+``````````````````"_8```
M`#H````+``````````````````"_:````#L````+``````````````````"_
M<````#P````+``````````````````"_>````#T````+````````````````
M``"_@````#X````+``````````````````"_B````#\````+````````````
M``````"_D````$`````+``````````````````"_F````$$````+````````
M``#K;_`P`"2Y!``?I_O_8.,0\```),#```!29L`0``!33^,0$```!+D"`!&G
MA``##>'C0/$0``3K;_#0``0']`<'XQ#P.``DP!```%)-T@?P,!`(XQ`0$``$
M!_$'``<`!P#`$```4DSC$!````0'\0T0XQ`0#``4P/3____E`````,`0``!2
M0.,0$```!`?Q#1#C$!`,`!3`]/___]4````8P!```%(TXQ`0```$!_$-$.,0
M$`P`%,#T____Q0```##`$```4BCC$!````0'\0T0XQ`0#``4P/3___^U````
M2,`0``!2'.,0$```!`?Q#1#C$!`,`!3`]/___Z4```!@P!```%(0XQ`0```$
M!_$-$.,0$`P`%,#T____E0```'C`$```4@3C$!````0'\0T0XQ`0#``4P/3_
M__^%````D,`0``!1^.,0$```!`?Q#1#C$!`,`!3`]/___W4```"HP!```%'L
MXQ`0```$!_$-$.,0$`P`%,#T____90```,#`$```4>#C$!````0'\0T0XQ`0
M#``4P/3___]5````V,`0``!1U.,0$```!`?Q#1#C$!`,`!3`]/___T4```#P
MP!```%'(XQ`0```$!_$-$.,0$`P`%,#T____-0```0C`$```4;SC$!````0'
M\0T0XQ`0#``4P/3___\E```!(,`0``!1L.,0$```!`?Q#1#C$!`,`!3`]/__
M_Q4```$XP!```%&DXQ`0```$!_$-$.,0$`P`%,#T____!0```5#`$```49CC
M$!````0'\0T0XQ`0#``4P/3___[U```!:,`0``!1C.,0$```!`?Q#1#C$!`,
M`!3`]/___N4```&`P!```%&`XQ`0```$!_$-$.,0$`P`%,#T___^U0```9C`
M$```473C$!````0'\0T0XQ`0#``4P/3___[%```!L,`0``!1:.,0$```!`?Q
M#1#C$!`,`!3`]/___K4```'(P!```%%<XQ`0```$!_$-$.,0$`P`%,#T___^
MI0```>#`$```45#C$!````0'\0T0XQ`0#``4P/3___Z5```!^,`0``!11.,0
M$```!`?Q#1#C$!`,`!3`]/___H4```(0P!```%$XXQ`0```$!_$-$.,0$`P`
M%,#T___^=0```BC`$```42SC$!````0'\0T0XQ`0#``4P/3___YE```"0,`0
M``!1(.,0$```!`?Q#1#C$!`,`!3`]/___E4```)8P!```%$4XQ`0```$!_$-
M$.,0$`P`%,#T___^10```G#`$```40CC$!````0'\0T0XQ`0#``4P/3___XU
M```"B,`0``!0_.,0$```!`?Q#1#C$!`,`!3`]/___B4```*@P!```%#PXQ`0
M```$!_$-$.,0$`P`%,#T___^%0```KC`$```4.3C$!````0'\0T0XQ`0#``4
MP/3___X%```"T,`0``!0V.,0$```!`?Q#1#C$!`,`!3`]/___?4```+HP!``
M`%#,XQ`0```$!_$-$.,0$`P`%,#T___]Y0```P#`$```4,#C$!````0'\0T0
MXQ`0#``4P/3___W5```#&,`0``!0M.,0$```!`?Q#1#C$!`,`!3`]/___<4`
M``,PP!```%"HXQ`0```$!_$-$.,0$`P`%,#T___]M0```TC`$```4)SC$!``
M``0'\0T0XQ`0#``4P/3___VE```#8,`0``!0D.,0$```!`?Q#1#C$!`,`!3`
M]/___94```-XP!```%"$XQ`0```$!_$-$.,0$`P`%,#T___]A0```Y#`$```
M4'CC$!````0'\0T0XQ`0#``4P/3___UU```#J,`0``!0;.,0$```!`?Q#1#C
M$!`,`!3`]/___64```/`P!```%!@XQ`0```$!_$-$.,0$`P`%,#T___]50``
M`]C`$```4%3C$!````0'\0T0XQ`0#``4P/3___U%```#\,`0``!02.,0$```
M!`?Q#1#C$!`,`!3`]/___34```0(P!```%`\XQ`0```$!_$-$.,0$`P`%,#T
M___])0``!"#`$```4##C$!````0'\0T0XQ`0#``4P/3___T5```$.,`0``!0
M).,0$```!`?Q#1#C$!`,`!3`]/___04```10P!```%`8XQ`0```$!_$-$.,0
M$`P`%,#T___\]0``!&C`$```4`SC$!````0'\0T0XQ`0#``4P/3___SE```$
M@,`0``!0`.,0$```!`?Q#1#C$!`,`!3`]/___-4```28P!```$_TXQ`0```$
M!_$-$.,0$`P`%,#T___\Q0``!+#`$```3^CC$!````0'\0T0XQ`0#``4P/3_
M__RU```$R,`0``!/W.,0$```!`?Q#1#C$!`,`!3`]/___*4```3@P!```$_0
MXQ`0```$!_$-$.,0$`P`%,#T___\E0``!/CK;_`P`"3C\/\X_W'C,/"H`"3C
M0/"@`"10(/"T04#PH$$P\*A!(/"TLD\`L.N[`"``#;)/`+'2!_#`L"C`Y?__
M_[+$2```3Z?$*```3[RY!``TP.4``!\;Q!@``$^\E0`0`*>$`+C`,```3Z7C
M4#````18H/"T[)H`!`#8N10`Z>-EL```!.LN``,`#98#9'JGJ@`#P.7___\&
MXQ#PJ``$P#```"""XP`0```$XS`@"``DXP`@```DN00`4L0K``!/XL!````@
M<^-`4!@`),0H``!/S>,@4!``)%B0\+2GG@`!I\0`Q^SI``,`V.P)__\`V$$P
M$`BG*``$IP$``:=T`(2(```!N10`0NP2``$`V.OD``,`#;D4`&'C0#````3C
M3E```"3K%@`#``WC8#`(``3C85```"2G*@`"ISL`$*<&_^/L:0`#`-BY%`"6
MZSD``P`-N10`2J=I``!!HU``Q"@``$^8Y4B@````P#````0^P.7___PG$B*G
MA`!5Q"@``$^)06#PO,#E___]_+D$`#:Y!`"2P"```![PP.4```#RN0(`(J>$
M`$?$*```3W/`Y?__^]C`Y?___175!_#`L"BG=`!;N00`*>MO\/@`!`?^P.7_
M__S'Q"L``$]<N0(`(J>$`$[`Y?___3W`,```3N+C(#````3C0K````22`$HG
MI_3_->,P,```!.,P4"``)*<H``5!,!`0&2ZG=/]SI_3_DL0H``!/-L#E___\
M.Z?T_Z?`4```3RKC(%````*GA``'P.4``!`"I_3_L+D$`#;`(```'FK`Y0``
M`)3$*P``3Q6Y`@`BIX3_H:?T_^RG:``$I_3_:\#E___]I*<I``'`Y?___2]!
M0/`(XS#P```$IPG_\+F``/"G^_]0UP?P`/``Z^_PH``D07#PH*=I``"G60``
MP"```$Z5XR`@```$P.7___Y_```'!P<'!P?`$```3M#`(```3LVY(``2!X[$
M&```3E^Y`@`1!XX'\<`0``!.P,`@``!.O;D)`!+K`0`#``KK,0`_``RY"``P
MZS,``0`*N0(`,P>.Q!@``$Y&N0(`$0>.P"```$ZD!_'KO_!8`"3`L```3IWC
M\/]@_W&5`+``IW0`%<`0``!./^,0$````J>$``C$*```3DO`Y?___*#`Y?__
M_[62`;``Z[_P^``$!_[`]/___[P'!^MO\#``)./P_V#_<;D"`(*GA`!:Q!@`
M`$WZXW`0```"IX0`4KD$`&/C`(```)2Y!`"8E0"``*>$`$^G#@`]IX0`"T&0
MD`'C`)```)25`)``IW3_]1N8XZ!P```"IX0`'[D4`)FY!`"WN00`2;D$`#BY
M!``JP.7___NF$B*G=``(02F@`)4](`"GA``/0;"P"..@L````J=T_^FY!``J
MZV_PT``$!_Y!J:`!N>EP.[D$`"KK0P`#``I00&``ZV_PT``$!_ZGJ0``N00`
M*NMO\-``!`?^IY@``*?T_[\'!P<'ZZ_P4``DX_#^R/]QLD\`L+D$`*+KNP`@
M``U!,/"@LD\`L=('\3"P*,#E___\S!(BIW0`'Q@26"#PN,`K``#P`*<N0`"G
MA``'PBT``*``IW0`$KD$`"JG.0`"P.7___TS$!*G&O__B!``'Z?T``2G&```
MN10`(=4'\3"P**=T``;KK_&(``0'_L#E___\;`<'ZV_P,``DX_#^P/]QLD\`
MH.NJ`"``#;)/`*&Y`@!BT@?Q.*`HIX0`!I4`8`"G=``+U0?Q.*`HIW0`D^MO
M\7``!`?^P.7___TGN0(`DJ>$__*Y!``IP.7___N>N0(`(J>$`&1!L"`3E2X@
M$Z=T``:5`+`!IX3_[Y4N(!.GA`!BIP@``+D$`!:Y!``[ITD``*=9``"R7@!!
MIQ3__K)>`%.G%/_^N0D`1KD)`%L:1:=*``*Y%``DP.7___H^X[#PH``DP%``
M`!R.N00`LJ=)__^G.0`!P.7___R_03#PJ+D$`"O`Y?__^OBG+O__N00`*Z>$
M``M8`/#`P`L``/``IPY``*>$`"G`Y?___":Y!``KP.7___QAN00`*<#E___[
M/+D"`"*G=/^@N00`*<#E___YX[D$`";`Y?__^BZG]/][E2ZP`:=T_YZ5`+`"
MIX3_@Z?T_YC`Y?___U>G]/_9P.7___NZ!P<'!P<'ZV_P,``DX_#_2/]QLD\`
M8.MF`"``#;)/`&&Y!`"RN00`H]('\+!@*)4],`"G=``$0:`P`:<(``"Y!``:
MIXD``+)>`(&G%/_^N0D`BD$P\*RY!``KP.7___YJN0(`(J>$`)VG"```I]D`
M`+D$`!*R7@#1IQ3__KD)`-*Y(0"-I\0`>N-P\*P`%,38``!,5.MW``,`#>,@
ML```E+D$`$N5`+``IW0`#:?T`.Y!0$`!XR!```"4E0!``*>$``:G+@`]IW3_
M];D)`$NY%`"402B0`KD$`(?C@-````C`Y?__^7?C((```"2Y`@`BIX0`.^,`
ML```D.,PT```!.-7,```!$(`4`!!X+`!&'"Y`@``IW0`$*?T`#_C$.```)!"
M$+`!0>#@`1AQN0(`$:>$`#-"</"@N00`M94]\*!!4%`!IW3_[)(]L`"GV0``
MXTV@``"00DVP`:?;``&Y`@!$IW3_]]4'\+!@**=T`)CK;_#H``0'_J>9``#C
MB:```)!"B2``IYL``;D"`(BG=/_WI_3_ZKD$`+6G]/_7Q-@``$O,XW#0```$
MXQ!P```"IX0`<+D$`$>GF```&`FGF@`!04!`".,P0````J=T__BG"@`#N10`
M,.LC``,`#<!0``!,).,04```$J=T`#?`X```3!SE3.````'`Y?__^.JY`@`2
MXQ#PH``DIX3_KKD$`#>Y%`!YZW<``P`-N00`1\#E___Y5^,@\*``!.,@T```
M)%"0\*SC4/"@``2GF@`!N10`F>LY``,`#4'C4`#E2.````"G]/\CN00`,KD$
M`"?`Y?__^:?C(/"@`"3C(-```"2Y`@`BIX3_>+D4`$GK=``#``VG]/_7IYD`
M`*?T_R.G*0`0IY@``*?T_Z/`Y?__^FD'!P<'ZW_P.``DX_#_6/YQXQ#PH`%Q
MN00`HKD$`).R3P"P08#PH.N[`"``#;D$`#BR3P"QITD/_\`@```:T]('$`"P
M*,#E___Y)!(BI\0`$>P"__\`V!@2N10`($$R\*"5`#``IW0`(A(`IW0`'L!0
M``!+)^/@4```!+D$`$FY!``ZXRZP```$P.7___C"XT#PH`%QU0=``+`HIW0`
M*NM_\.`!!`?^&!"Y%`!QISD`+[D$`$>Y!``HP.7___CZN0(`(J>$_]:Y!``Z
MN00`5\"@``!*][D$`$CCD*````3C*;````3`Y?__^92G]/_2P.7___GOP!``
M`$KDP%```#JIQ$@``$KBZV_P,``DP#```!IQX[`0```$X_#_6/]QLD\`H.NJ
M`"``#;)/`*'C*Z````3`8```&[[`Y?__^IJY!`!6Y4CPH```P$````KBXRN@
M```$P#```!I;P.7___CYZV_PV``$!_X'!P<'LD\`(,`0``!*INLR`"``#>-`
M$```!+)/`#'`4```.F/C)#````3$2```2IG`,```&BO`]/__^F?K;_`P`"3C
M\/](_7'C$/"P`G&R3P"0ZYD`(``-LD\`D=('$`"0*$&P\*[C@/"O`7'`Y?__
M^3S`````&BGC`/"@`"2Y!`!BP%```!H;ITD0`:<Y``&Y!``KP.7___HHITD0
M`+D$`"NY!``XP.7___@_$B*G1``JN00`8J<J``&Y%``BP.7___>#N0(`HJ>$
M``^Y%`"VN00`.+D$`$O`Y?__^E9!.Z``D@`P`.-`\+`"<=4'0`"0**=T``RY
M!``JZV_PZ`($!_ZGJ0``I_3_\,#E___Y+0<'!P?`]/___Y0'!^MO\#``)./P
M_K#^<>,0\4@!<;D$`+*Y!`"3LD\`<$$P\+3K=P`@``W`(```&<.R3P!QT@<0
M`'`HP.7___OHISD`+[D$`**Y!``KP.7___D/N0(`(J>$`!C`(```&;"Y!``[
MP.7___T_N00`*^,0\4@!<=4'$`!P**=T`._K;_&``00'_KD$`"G`Y?__^!#`
M,```&9S`Y?__]UJY`@!BIX3_W4&0\4A!@/"XE0!@`*>$`*:Y`@"JIX0`#J<(
M``"Y!``VN00`*K)=`#*G%/_^IX0`AJ<(``"G20``N00`5K)>`$6G%/_^N>E@
M).,03___<;DA`&&GI``WN>E@`:<!``&GA``/E2\0`*=T`"&2`!``XQ`?__]Q
MN2``8:>$`!CKX``!``R5+Q``IW0`$9(`$`#K+Q___U6G=``*ZP`?__]2XQ`?
M_O]QI^?_[Z<(``"G*0``N00`-K)>`".G%/_^N0D`)J<(``"G20``N00`6[)>
M`$6G%/_^N0D`2T$$(`'"#@``#_^G)/]JP.```!D@X[#PJ``DX^#PH``DP%``
M`!F.ITD0`*<Y``&Y!``IP.7___D.N00`.+D$`"G`Y?__]T<2(J=T``Q88/#0
MP&L``/``PFT``(``IX0`)\`P```8]J<I``#`Y?__]K*Y`@!BIX3_-94`8`"G
M=/]>N0(`JJ>$``:5+J``IX0`":<I``'`8```&,^G]/^GE0"@`:>$_]^G]/_U
MISD``;D$`"G`Y?__^+X2(J=T_].Y!``YP"```!B^P.7___Q/N00`*<#E___W
M+J?T_PW`Y?__]_D'!P<'Z[_P6``DISD`+^/P_V#_<;D$`++`Y?__^(JY`@`B
MIX0`!$&P(`&Y!``KZ[_P^``$P/3___<,!P?KG_!(`"3C\/]8_G&R3P"@XQ#P
MH`%QZZH`(``-LD\`H=('$`"@*+D"`#*GA`!DE0`P`*>$`&"G"```IYD``+D$
M`".R7@"2IQ3__KD)`)/L20`!`-G"3@``$`"G)`!P0;#PH+D$`"O`Y?__^+7C
M2;___W&Y(0!+I\0`'KGIL`2G00`!IW0`2>LP``$`#)4O0`"G=``1D@!``.LO
M3___5:=T``KK`$___U+C0$_^_W&G-__OISD`+[D$`"O`Y?__^!NY`@!2IX0`
M%[DA`%NG)``SN00`*\#E___VGN/@\*`!<=4'X`"@**=T`"[KG_#P`00'_N,0
M\*`!<=4'$`"@**=T`"+`(```&`GKG_#P`03`]/__]H&5+T``IW3_S9(`0`#C
M0$___W&Y(`!+IW3_KJ?T_\*2`%``I_3_S:<I``"G]/_.P.7___<WZZ_P4``D
MX_#_4/]QLD\`H$&P\*3KJ@`@``VR3P"AT@?PJ*`HN00`.\`@```7X<#E___Y
M_;D"`"*GA``PXT#PI``4Q"@``$?WZQ0``P`-XQ`@```(XU`0"``$XU`0```D
MN0(`5:>$_^#C`!`0``3C`!`(`"1!$!`(N0(``*=T__:Y!``[P"```!>SP.7_
M__G/N0(`(J=T_]2Y!``[P"```!>LP.7___G#N0(`(J>$`##C$/"D`!3$6```
M1[WKX0`#``WCX%````CC`.`(``3C`.```"2Y`@``IX3_X.,PX!``!.,PX`@`
M)$'@X`BY`@`SIW3_]KD$`#O`(```%W[`Y?__^96Y`@`BIW3_U+D$`#O`(```
M%W;`Y?__^8FY`@`BIX0`,.-0\*0`%,3H``!'@^M%``,`#>-`X```".,P0`@`
M!.,P0```)+D"`#.GA/_@XR!`$``$XR!`"``D04!`"+D"`"*G=/_VN00`.\`@
M```72,#E___Y6[D"`"*G=/_4N00`.\`@```70<#E___Y3[D"`"*GA``PXS#P
MI``4Q"@``$=)ZQ,``P`-XQ`@```(XT`0"``$XT`0```DN0(`1*>$_^#C`!`0
M``3C`!`(`"1!$!`(N0(``*=T__:Y!``[P"```!<3P.7___DAN0(`(J=T_]2Y
M!``[P"```!<+P.7___D5N0(`(J>$`##C$/"D`!3$2```1P_K40`#``WC4$``
M``CC`%`(``3C`%```"2Y`@``IX3_X./@4!``!./@4`@`)$%04`BY`@#NIW3_
M]KD$`#O`(```%MW`Y?__^.>Y`@`BIW3_U+D$`#O`(```%MG`Y?__^-NY`@`B
MIX0`,.-`\*0`%,18``!&U>LT``,`#>,P4```"./@,`@`!./@,```)+D"`.ZG
MA/_@XR`P$``$XR`P"``D03`P"+D"`"*G=/_VN00`.\`@```6J\#E___XK;D"
M`"*G=/_4N00`.\`@```6=\#E___XH;D"`"*GA``PX^#PI``4Q"@``$:;ZQX`
M`P`-XQ`@```(XS`0"``$XS`0```DN0(`,Z>$_^#C`!`0``3C`!`(`"1!$!`(
MN0(``*=T__:Y!``[P"```!9)P.7___ASN0(`(J=T_]2Y!``[P"```!9KP.7_
M__AGN0(`(J>$`##C$/"D`!3$.```1F'K00`#``WC0#````CC`$`(``3C`$``
M`"2Y`@``IX3_X.-00!``!.-00`@`)$%`0`BY`@!5IW3_]KD$`#O`(```%CW`
MY?__^#FY`@`BIW3_U+D$`#O`(```%C;`Y?__^"VY`@`BIX0`,.,P\*0`%,1(
M``!&)^OC``,`#>/@0```".-0X`@`!.-0X```)+D"`%6GA/_@XR#@$``$XR#@
M"``D0>#@"+D"`"*G=/_VN00`.\`@```6",#E___W_[D"`"*G=/_4N00`.\`@
M```6`<#E___W\[D"`"*GA``PXU#PI``4Q.@``$7MZQ4``P`-XQ#@```(XR`0
M"``$XR`0```DN0(`(J>$_^#C`!`0``3C`!`(`"1!$!`(N0(``*=T__:Y!``[
MP"```!73P.7___?%N0(`(J=T_]2Y!``[P"```!64P.7___>YN0(`(J>$`##C
M$/"D`!3$*```1;/K,0`#``WC,"````CC`#`(``3C`#```"2Y`@``IX3_X.-`
M,!``!.-`,`@`)$$P,`BY`@!$IW3_]KD$`#O`(```%6;`Y?__]XNY`@`BIW3_
MU+D$`#O`(```%9+`Y?__]W^Y`@`RIX0`",`@```5?L#E___XX;D$`#O`(```
M%8G`Y?__]VVY`@`RIX0`",`@```5B,#E___XS[D$`#O`(```%8;`Y?__]UNY
M`@`RIX0`&<`@```5)\#E___XO=4'\*B@**=T`"+`,```%8+`(```%3GKK_$`
M``3`]/__^*RY!``[P"```!5KP.7___<XN0(`,J>$_^7`(```%3+`Y?__^)JG
M]/_=P.7___1)!P<'!^N_\%@`),`@```5(N/P_U#_<;)/`+!!,/"DZ[L`(``-
MLD\`L=('\*BP*,#E___W#[D"`"*GA``;OP$@`*>$`!?`!P```#"YA``0N0,`
M,>Q#/[\!5;D4`"35!_"HL"BG=``*Z[_Q"``$!_ZG2```I_3_\\#E___T"V``
M\(!@(/"(8$#PD&!@\)BR3P`0ZS_P&``DX_#_./]QZS$`(``-N00`0K)/`#%!
M`/%H02#PR,1H``!$^4%0\*#2!_#`,"CC(/"X`"3C`/"P`"3E2/"@``'E2/"H
M``#C(&````2G.0`!P.7___.DIRD`_\#E___S7Z=)``*G.0``ZX_P0``DX_#_
M4.]QXQ#PJ!!QN00`@K)/`*#KJ@`@``VR3P"AT@<0`*`HP.7___(#[)+__P#9
M[`DP@`!5N0(``*>D``NG"___P"'__P``N8$``J<+``&Y"0"00;#PH+D"`)FG
M1`"HITD``+D$`#FY!``HP.7___'?IR___Z>$`+7`00`!``BY!``[N00`*,#E
M___SX:<N__^GA`"AN10`,L(^````!Z?$`'[C$[_X_W&Y(0`;IT0`=^Q!/K\`
M5<!0``!$A=4'4``0`*>$`(+C$!___W&Y(0`;IT0`9;D"`$2GA``OIT\``:>$
M`!RG3P`"IX0`#<#@``!$:M4'X``0`*>$`&?C$!___W'`(```1%_5!R``$`"G
MA`!<XQ`?__]QP#```$14U0<P`!``IX0`4>,0'___<;DA`!NG1``TP$```$1%
MU0=``!``IX0`0N-0'___<<#@``!$.KD$`!75!^``4`"GA``UXQ!?__]QP"``
M`$0MU0<@`!``IX0`*L0(``!$)>,07_[_<>,`7_[_(*>$`!_C$%_]_W&Y(0`;
MIZ3_T,*4``$``,*<__\``*=T_URG*?__XX#PJ!!QU0>``*`HIW0`&.N/\/`0
M!`?^N>FP(;D(`"FG]/_PP"```!/\P.7___[0P"```!/OP.7___[*P.7___+/
MZ^_P<``DX_#_8/]QP.7___"FP.7___"#N0(`(J>$``7C("````3K[_$0``0'
M_@<'ZV_P,``DX_#_0/]QLD\`H+D$`&+KJ@`@``U!,/"TLD\`H<`@```3RM('
M\+B@*,#E___U?;D"`+*GA``8E0"P`*>$`!2Y!``VP.7___"PN0(`(J>$`!O5
M!_"XH"BG=`!4ZV_P\``$!_[5!_"XH"BG=`!+N00`-L`@```3H.MO\/``!,#T
M___VOZ<(``"Y!``[N00`%J=)``"R7@!#IQ3__K)>`"&G%/_^N0D`2[D)`"9!
M(D`"P.7___"*P````!,6X[#PJ``DXP#PH``DN00`LL!0```3@Z=)__^G.0`!
MP.7___,%U0?PN*`HIW0`#;D$`#O`(```$V+K;_#P``3`]/__]H'`Y?__\C('
M!P<'!P?K;_`P`"3C\/X0_W&R3P!PZW<`(``-LD\`<<`0``!#.[D$`-)!H/#$
MP"```!++N00`.M('\>AP*-(/\,@0$-('\-@0(-(O\/@0*-(/\.`06-('\/`0
M:,#E___TX;D"`+*GA``&E0"P`*=T`FK`Y?__[];`Y?__[[.Y`@`BIX0!%^.P
M(````J>$`1*G"```ISD``+D$`$NR7@`TIQ3__KD)`#OK(P`!``VG*P`!P.7_
M__`&E0"P`.-@L```E+D$`)*Y!`""IX0`&[F$`&:Y!``IP%```!+WITG__Z<Y
M``'`Y?__\GU!L+`!09"0`N-@L```E)4`L`"G=/_I09#Q`,`@```2KZ?T``FG
MFP`(XR"?^/\"IX0`'KD$`#K`Y?__]'^Y`@"RIX3_\I4`L`"GA/_NP.7___3D
M$B*GA/_HN00`*\#E___PO+D"`&*G=``<09#PR.-@D````J>$`!65`&``IX0`
MH;D$`";`Y?__],@2(J=T`(RGFP`(XV"0```"IW3_[Z<(``"Y!`!8N00`)J<Y
M``"G20``LEX`,J<4__ZR7@!%IQ3__KD)`#:Y"0!(&C2G.@0$N10`L[D$`"O`
MY?__[W[`````$H;C@/"P`"3C`/"H`"2Y!`"2P%```!)VITG__Z<Y``'`@```
M$?GC@/"@`"3`Y?__\?.G.0'`N00`*<#E___PW*<N__^G=``+P.7___"E6&`@
M`*=N`!&G=`%V03#Q*+D$`"G`Y?__\4@8@A(BIW0`"UC@\4#`ZP``\`"G[D``
MIX0`>,2H``!"%+D$`&GC4-````3`0```$ESC(*````2G.0`!P.7___$8I[D`
M`-4'\>AP**=T`@>Y!``KZV_R(``$!_ZGFP`(N00`)L#E___P%+D"`&*GA/]<
MI_3_<J=I``"G]/]N08#PX.,@@````J>$`!:Y!``ZP.7___.NN0(`4J>$``:5
M`%``IW0`&:>+``CC((````*G=/_NIRD`#<"P```1Z<#E___NYZ=H`%.Y!`"2
MN00`@J?T_N;`Y?__[]RY`@"RIX3_Y*<(``"GZ0``N00`&[)>`.&G%/_^N0D`
MZ^LN``$`#:<K``&G]/Z^6&#Q1,#E___N<!EBIW3_A%@0\4#`&P```?^G'@'`
MIW3_>[D$`"O`Y?__[J^Y!``ZN00`LL`@```1_L#E___S5;D"`#*GA`#RXR#0
M```$P.7___='N0(`8J>$`.BG"```ITD``+D$`#:R7@!#IQ3__KD)`$:G3@`#
MI\0`'KD4`"3`4```$=OCXF_\_W&R70!>IQ3__J=T`!"G3@`$IX0!-Z=*__NY
M%``404%@`)4O0`"GA`$MN00`.L`@```1%\#E___S$[D"`**GA`"UXP"@``"4
M$@"GA`"OIPX`,*>$`*O`,```$3O`(```$0#`Y?__]&BY!`!IP.7__^_7P$``
M`!(%P#```!#1XT#PL``DXS#PH``DXR#PJ``DP%```!&BN00`*Z=)__^G.0`!
MP.7___"\I_0`,L#E___O=U@@(`"G+@`1IW0`-*>*``'`H```$*S`Y?__[ZG`
M4```$=>Y%``(XU#PN``DXR#PJ``DXZ#PH``DN00`:>,`\+``)+D$`"O`4```
M$76G2?__ISD``<#E___PBJ<Y`<"Y!``KP.7__^]SIR[__Z>$_\>Y!``IP.7_
M__`ZN00`.\`@```0:,#E___S_KD$`"O`Y?___/FG]/ZWN10`%L0X``!`LN,0
M\*``)+D$`&GC4-````3`0```$-GC(#````2G.0`!P.7__^^SI_3^F\#E___\
MVM4'\>AP**=T`)^Y!``KZV_R(``$P/3__^ZQXV#0```$I_3_%[D$`":G.0``
MP.7___`%N00`TA(BIX3_3<#E___[H;D"`&*G1/]&ITD``.,P;_;_<;D$`"W`
MY?__[:^G20`&03#QN;D$`"W`Y?__[[:G+P`&IW0`:\`0```P%-4%$`#QN:=T
M_R?C,&_._W&G20``N00`+<#E___MD+D$`"VG20`H0=#QO[D$`#W`Y?__[Y6G
M+P`HIW0`2L#@```1'\!@```/ZY(`\>?C8/"@`"3CX/"P`"3CT/"H`"2Y!`!I
MP%```!"PITG__Z<Y``&Y!``KP.7__^_2I_3_4^/0T`@``J>$_M*G"```IRD`
M`+D$`#VR7@`CIQ3__KD)`"W"+@````.GQ/[!XU+?_/]QP.```!"`LET`Y:<4
M__ZYXH!MI_3^L\#E___NZ<`@```0=<#E___ZV^M_\#@`),"@```_U>,0H```
M!./P_U#_<;)/`+!!@/"DZ[L`(``-P"````^@LD\`L;D$`#C2!_"HL"CCD;``
M``32`)"QD+#`Y?__\9VY`@`BIX0`!I4Q(`"GA`#4P.7___=^XS"@```$XY.P
M```$N00`*:=9``.G20`!P#```!!0P.7__^TPN0(`DJ>$`![C0)`0``3C<*``
M``3C,$````3C)[````3`0```$#O`Y?__[2KC4)`0``3C,%````210#`-IW0`
MMN-PH```!*=9``/C)[````2G20`!P#```!`DP.7__^T`N0(`DJ>$`!JY!``X
MP"````\?P.7___%$N0(`0J>$`(7C()`0``3C,"````3C)[````3`Y?__[/3C
MH*````2G20`!XWJP```$P#````_[N00`)\#E___L-,!````/_KD$`#*Y!``G
MP.7__^S:XSJP```$D@`PL<`@```.Y;D$`#C`Y?__\0W$*P``/XZY!`""N0(`
M(J>$`"ZG.0'`N00`*,#E___MS>P"``$`V,(/`````:?$`!:G+@`1IX0`$KD$
M`%+$N```/VRY!`!(P"````_8XS"P```$P.7__^Y1U0?PJ+`HIW0`.NM_\.@`
M!`?^Q"@``#]5P.7___O&Q"L``#]3N00`@KD"`"*G=/_'P"````^FP.7__^XS
ME0`@`:>$_S6G]/\JX^"0$``$Q!@``#\WXR#@```$XS`0```$P.7___-JI_3_
M>N,GL```!,#E___MMJ?T_T;`Y?__[<$'!P<'ZY_P2``DX_#_4/]QLD\`H+D$
M`)+KJ@`@``VR3P"AT@?PJ*`HP.7___72ISD`+[D$`++`Y?__[D.Y`@`BIX0`
M!$&P(`&Y!``KP.7__^S(03#PI+D$`++`(```#G+`Y?__\&ZY`@`2IX0`%.,`
M$```E!(`IX0`#J<.`#"GA``*N0(`F:>$``:5`)``IW0`"]4'\*B@**=T`"#K
MG_#X``0'_KD$`"NG20`$P#````ZCP.7__^PE$B*G=/_LU0?PJ*`HIW0`"KD$
M`"GKG_#X``3`]/__\.W`Y?__[5('!P<'!P=!4"`XIPD`!.MO\#``)./P_-#_
M<;)/`*!!$/"HZZH`(``-LD\`H=('\RB@*.-`4```!.,P4`@`!.NT`"``#..P
M$```).MC`"``#.-@$!``),!*`````.-`$`@`),`Z`````.,P$!@`)$%04!"G
M&P`@IP?_WN,P\1``!..`\1@`!.,0\2``!..0\*@`!.-`\+``!$&P\+BG60!`
MN00`<>/0L```!+D$`.WCX+`P`(*Y@@#CN8(`Z>P>(+\A5>P>(#X!5N,0L'``
M)+D$`#BY!`"4N00`AZ>[``BG5PKFXP`@"``$XP#PH``DXU`@$``$X[`@&``$
MN>>PE;F``)"Y@@";XT`@```$ZV```@`,[#0@OR55[&``(1Y6[#0@.@56[.8@
MOP!5XW#PL``$N>?@U<)Z6H)YF;F``-2Y"`![N8(`U>,0\*@`!+GH<(W"&EJ"
M>9GC$"`@``BY"``3N0@`&>R1(+\`5>P!.[\E5>P)`#H%5KD(``CK-``"``SL
M<""_`%7L-``A'E;LT#N_)57L@R"_`%7LUP`Z!5:Y@@!CXQ#PN``$N8``:<(:
M6H)YF;F"`&ZY"``5XP#PP``$N0@`%L(*6H)YF;D(`!VY"``.Z^D``@`,[.D`
M(1Y6N8(`/NR1(+\`5>QA.[\E5;GD<!.Y!``V[#D`.@56[&X@OP!5N8(`&./0
M\,@`!+D(`!#"VEJ">9FY"``3N>B`#>LW``(`#.R!.[\E5>PW`"$>5NQQ(+\`
M5>R'`#H%5KF"`./C$/#0``2Y@`#IPAI:@GF9N8(`YKD(`."YZ&`!N0@`Z.QC
M(+\`5>N)``(`#.R)`"$>5KF"`#CLGB"_`%7LWCN_)56YY'#CN00`/>PY`#H%
M5KF"`.;C$/#8``2Y"`#@PAI:@GF9N0@`X[GH8`'K-P`"``SL:""_`%7L-P`A
M'E:Y@@"#['X@OP!5[-X[OR55N>20Z+D$`(WLAP`Z!5:Y@@#FXQ#PX``$N0@`
MX,(:6H)YF;D(`.BYZ&`!ZXD``@`,[&,@OP!5[(D`(1Y6N8(`..R>(+\`5>S>
M.[\E5;GD<..Y!``][#D`.@56N8(`YN,0\.@`!+D(`.#"&EJ">9FY"`#CN>A@
M`>LW``(`#.QH(+\`5>PW`"$>5KF"`(/L?B"_`%7LWCN_)56YY)#HN00`C>R'
M`#H%5KF"`.;C$/#P``2Y"`#@PAI:@GF9N0@`Z+GH8`'KB0`"``SL8R"_`%7L
MB0`A'E:Y@@`X[)X@OP!5[-X[OR55N>1PX[D$`#WL.0`Z!5:Y@@#FXQ#P^``$
MN0@`X,(:6H)YF;D(`..YZ&`!ZS<``@`,[&@@OP!5[#<`(1Y6N8(`@^Q^(+\`
M5>S>.[\E5;GDD.BY!`"-[(<`.@56N8(`YN,0\0``!+D(`.#"&EJ">9FY"`#H
MN>A@`>N)``(`#.QC(+\`5>R)`"$>5KF"`#CLGB"_`%7LWCN_)56YY'#CN00`
M/>PY`#H%5KF"`.;C$/$(``2Y"`#@PAI:@GF9N0@`X[GH8`'K-P`"``SL:""_
M`%7L-P`A'E:Y@@"#['X@OP!5[-X[OR55N>20Z+D$`(WLAP`Z!5:Y@@#FXQ#Q
M$``$N0@`X,(:6H)YF;D(`.BYZ&`!ZXD``@`,[&,@OP!5[(D`(1Y6N8(`..R>
M(+\`5>S>.[\E5;GD<..Y!``][#D`.@56N8(`YN,0\1@`!+D(`.#"&EJ">9FY
M"`#CN>A@`>LW``(`#.QH(+\`5>PW`"$>5KF"`(/L?B"_`%7LWCN_)56YY)#H
MN00`C>R'`#H%5KF"`.;C$/$@``2Y"`#@PAI:@GF9N0@`Z+GH8`'KB0`"``SL
M8R"_`%7LB0`A'E:Y@@`X[)X@OP!5[-X[OR55N>1PX[D$`#WL.0`Z!5:Y@@#F
MXQ#Q*``$N0@`X,(:6H)YF;D(`..YZ&`!ZS<``@`,[&@@OP!5[#<`(1Y6N8(`
M@^Q^(+\`5>S>.[\E5;GDD.BY!`"-[(<`.@56N8(`YN,0\3``!+D(`.#"&EJ"
M>9FY"`#HN>A@`>N)``(`#.QC(+\`5>R)`"$>5KF"`#CLGB"_`%7LWCN_)57C
M$/$X``2YY'#CPAI:@GF9N00`/>PY`#H%5NS8(+\`5;F"`.:Y"`#@N>A@`;D(
M`./K-P`"``SL-P`A'E;L?CN_)56YYS!H['X@.@56XX#Q0``$P.H`````PHI:
M@GF9N>C0&+F``&GKC@`"``RY@@!M[(X`(1Y6N0@`8.L)``(`#+D(`&?L"0`A
M'E;L<R"_`%6YYP#3[)8[OR55N8``WNR6(#H%5KF"`->Y"`#1N>>`$+D(`-FY
M@@`6[.T[OR55[.T@.@56XS#Q2``$XY#Q4``$PCINV>NAPIINV>NAN0@`-[D:
M`)"Y&@`Q['8BOSY5N0@`/NQV`B$>5NSC.[\E5;GG<!CLXR`Z!5:Y@@`=[&TB
MOSY5N1H`D>QM`B$>5KD(`)[CX/%8``3"ZF[9ZZ&Y&@#HN>=@A[F"`(/L"3N_
M)56Y&@#H[`D@.@56XX#Q8``$N0@`X,**;MGKH>P>.[\E5;D:`(?L'B`Z!5;L
M<R*_/E7L<P(A'E;C,/%H``2YYW#6PCINV>NAN8(`V;D:`#:Y&@"-[&DBOSY5
MN0@`@>QI`B$>5NR8.[\E5>R8(#H%5KGG8!>SP0!IN8(`'N.0\7``!+D:`#'"
MFF[9ZZ&Y&@"7L\T`=KD(`#?LTSN_)57LTR`Z!5;L?B*_/E7C$/%X``3L?@(A
M'E;"&F[9ZZ&YYW#FN1H`%KF"`.CL:"*_/E6Y&@">[&@"(1Y6N0@`G;GG8-?L
MB3N_)56Y@@#3[(D@.@56N1H`'>/@\8``!+D(`!C"ZF[9ZZ'L@R*_/E6Y&@#G
M[(,"(1Y6[`$[OR55N>>`UNP!(#H%5KF"`-GC,/&(``2Y&@#MPCINV>NAN0@`
MX+D:`#;L:2*_/E7L:0(A'E;LGCN_)57LGB`Z!5:YYV`(L\$`>;F"``'CD/&0
M``2Y&@`PPIINV>NAN1H`F+/-`(>Y"``X[-,[OR55[-,@.@56['$BOSY5['$"
M(1Y6XQ#QF``$N>=P!L(:;MGKH;F"``ZY&@`6N1H`D.QN(K\^5;D(`)WL;@(A
M'E;LZ3N_)56YYV#7[.D@.@56N8(`T^.`\:``!+D:`!W"BF[9ZZ&Y"``>N1H`
MA^SC(K\^5>P!.[\E5>SC`B$>5NP!(#H%5KGGX-;C,/&H``2Y@@#9PCINV>NA
MN1H`C;D:`#:Y"`"`[&DBOSY5[&D"(1Y6[)@[OR55[)@@.@56N>=@#K/!`&FY
M@@`!XY#QL``$N1H`,,*:;MGKH;D:`)ZSS0#FN0@`/NS3.[\E5>S3(#H%5NQQ
M(K\^5>QQ`B$>5N,0\;@`!+GG<`;"&F[9ZZ&Y@@`(N1H`%KD:`)#L:"*_/E6Y
M"`"=[&@"(1Y6[(D[OR55N>=@U^R)(#H%5KF"`-/CX/'```2Y&@`=PNINV>NA
MN0@`&+D:`.?L@R*_/E7L`3N_)57L@P(A'E;L`2`Z!5:YYX#6XS#QR``$N8(`
MV<(Z;MGKH;D:`.VY&@`VN0@`X.QI(K\^5>QI`B$>5NR>.[\E5>R>(#H%5KGG
M8`BSP0!YN8(``>.0\=``!+D:`##"FF[9ZZ&Y&@"8L\T`A[D(`#CLTSN_)57L
MTR`Z!5;L<2*_/E6SP0`-['$"(1Y6[-XBOSY5N>=P!NS>`B$>5KF"``ZYY]"'
MXQ#QV``$N8(`@\(:;MGKH;D:`!:SS0!@N1H`D+D:`!BY"`"6[(,BOSY5[.D@
MOP!5[(,"(1Y6[`D[OR55N>>`;>P.`#H%5KF"`):Y"``0XS#QX``$PCINV>NA
MN1H`-^QQ(+\`5>P1.[\E5>P7`#H%5KD:`#GCD/'H``2Y"``QPIJ/&[S<ZQX`
M`@`,N1H`G>P>`"$>5NS1(+\`5;GDT`BSP0`I[.,[OR55[),@OP!5XV#Q\``$
MN>80..SI`#H%5KF``#?":H\;O-RY@0`PL\T``KD(`#"Y!``&N0@`/KD:``CK
MYP`"``SC8/'X``3LYP`A'E;":H\;O-RYY-!^N8$`'KGHT-:Y@``9N8$`%[D(
M`!#L@R"_`%6SP0!M[#,[OR55[#@`.@56N0@`,>L9``(`#.P9`"$>5NS1(+\`
M5;GDT`ZYYA">N8``F+F!`)"SS0`&[',@OP!5N0@`D.PS.[\E5>-@\@``!.PW
M`#H%5L)JCQN\W+D$``:Y&@`.Z^@``@`,[.@`(1Y6N>30CKD(`).Y@0`>[#D@
MOP!5N8``%^R9.[\E5;F!`!CLDP`Z!5:Y"``0ZX<``@`,N0@`&>R'`"$>5N-@
M\@@`!.QX(+\`5<)JCQN\W+GD<`ZYZ-#6[)$[OR55L\$`/>S1(+\`5;GF@!ZY
M@``3N8$`$+/-``/LG0`Z!5:Y"``0XV#R$``$PFJ/&[S<N00`!KD:``[KXP`"
M``SLXP`A'E:YYN`XN>1PCKD(`!FY@``][&$@OP!5[)$[OR55N8$`..R6`#H%
M5KD(`#"Y"``Y[(,@OP!5ZQT``@`,[!T`(1Y6XP#R&``$N>80WNR3.[\E5<(*
MCQN\W.R8`#H%5K/!`'VSP0`I[-$@OP!5N00`,..0\B``!+D(`#?"FH\;O-RY
MY-!^N1H`GK/!`$.SS0#BL\T`!+/!`&FSS0`WZY8``@`,N8``-NR6`"$>5KF!
M`#>YY-!IN0@`,+F!`!FY"``^N8``&+/-``:Y@0`6X^#R*``$N0@`$,+JCQN\
MW.QS(+\`5;GHT-[L,SN_)57L-P`Z!5:Y"``QZQ@``@`,[!@`(1Y6[.$@OP!5
MN>3@">QC(+\`5;/!`!WL@SN_)56YYA`YN8``-[F!`#"SS0`![(8`.@56N0@`
M,./0\C``!.,`\C@`!,+:CQN\W,(*CQN\W+D:`-GKEP`"``SLEP`A'E:YY.!Y
MN8$`&;F``!:Y@0`7N0@`';GHX."Y"``X[(,@OP!5[#,[OR55[#@`.@56N0@`
M,>L6``(`#.P6`"$>5NS1(+\`5;GDT`GL<R"_`%6SP0!>[&,[OR55N>80.;F`
M`#BY@0`PL\T`!>QG`#H%5KD(`##CX/)```3C`/)(``3"ZH\;O-S""H\;O-RY
M&@#IZY@``@`,[)@`(1Y6N>30B;F!`!FY@``7N8$`&+D(`!ZYZ-#0N0@`-NQC
M(+\`5>PS.[\E5>PV`#H%5KD(`#'K%P`"``SL%P`A'E;L@2"_`%6YY(`)[.,@
MOP!5L\$`+>QS.[\E5;GF$#FY@``VN8$`,+/-``+L?@`Z!5:Y"``PX]#R4``$
MXP#R6``$PMJ/&[S<P@J/&[S<N1H`V>N6``(`#.R6`"$>5KGD@&FY@0`9N8``
M'KF!`!:Y"``=N>B`@+D(`#?L<R"_`%7L,SN_)57L-P`Z!5:Y"``QZQX``@`,
M[!X`(1Y6[-$@OP!5N>30">QC(+\`5>SC.[\E5;/!`$BYYA`YN8``-[F!`#"S
MS0`$[.8`.@56N0@`,..`\F``!,**CQN\W+D$``BY&@`)ZY<``@`,[)<`(1Y6
MN>30>;F!`!FY@``6N8$`%[D(`!"Y"``^XX#R:``$[.,@OP!5PHJ/&[S<[#,[
MOR55[#X`.@56N0@`,>L6``(`#.P6`"$>5NQA(+\`5;GD8`GL<R"_`%6YZ-#8
M[(,[OR55L\$`';GF$#FY@``^N8$`,+/-``'LAP`Z!5:Y"``PX]#R<``$N0@`
M.,+:CQN\W+D$``VY&@`)[-,@OP!5ZYX``@`,[)X`(1Y6[.,[OR55N>1@B;F!
M`!GL[0`Z!5:Y@``7XS#R>``$N8$`&,(ZCQN\W+D(`!"YZ&`#N0@`X>QN.[\E
M5>QN(#H%5NL7``(`#+/!`%;L%P`A'E;C8/*```3L@2"_`%6YYA!YN>2`.;F`
M`'W":H\;O-RY@0!SN1H`:;D(`'"SP0!VL\T`E>-@\H@`!+GHD)?":LIBP=;L
M"3N_)57K?0`"``SL"2`Z!5;L?0`A'E:Y!`#0N>2`-[GH@(;`Z@````"Y@0`7
ML\$`*+F``!ZSS0`'N8$`$^N.``(`#+D(`!#LC@`A'E:Y"``=L\T`8KGG@-?C
M,/*0``2Y@@#9PCK*8L'6N1H`;;D:`#?LX3N_)57L>2*_/E7LX2`Z!5;L>0(A
M'E:Y"`#FL\$`8^P..[\E5;GG<#CL#B`Z!5:Y@@`Q[&$BOSY5XY#RF``$[&$"
M(1Y6PIK*8L'6N>=@U[D:`)BY@@#>L\$`";/-`):Y&@"3N0@`D+/-``#L&3N_
M)56Y&@`-[!D@.@56N0@`$.PQ.[\E5>PQ(#H%5K/!`!.SS0#1XX#RH``$XS#R
MJ``$PHK*8L'6PCK*8L'6N1H`A[D:`#;L?B*_/E7L?@(A'E:YYW#F[&DBOSY5
MN8(`Z>QI`B$>5KD:`(ZYYV`'N0@`C;F"``'LF#N_)56Y&@`P[)@@.@56N0@`
M.>S3.[\E5>S3(#H%5NR1(K\^5>/@\K``!.R1`B$>5L+JRF+!UKGGD`:Y&@#G
MN8(`"+D:`."Y"`#M[-X[OR55[-X@.@56XQ#RN``$L\$`?<(:RF+!UN/0\L``
M!+D:`!;"VLIBP=;L:"*_/E6Y&@#9[&@"(1Y6N>=@B;F"`(/L<R*_/E6Y&@`8
M[',"(1Y6L\T`E[GG<(:Y"``9N8(`CNP!.[\E5>,P\L@`!.P!(#H%5L(ZRF+!
MUKD:`#:Y!`!M[-XBOSY5N1H`:+D(`&#LW@(A'E:YY]#GN8(`X>.`\M``!.R6
M.[\E5;D:`#[LEB`Z!5;"BLIBP=:Y"``YN1H`A^P#.[\E5>QQ(K\^5>P#(#H%
M5NQQ`B$>5N,0\M@`!+GG<.W"&LIBP=:Y@@#FN1H`'>S6(K\^5>S6`B$>5KGG
MT&>Y@@!CN1H`CKD:`!:Y"`"`[),BOSY5[`@[OR55[),"(1Y6[`@@.@56N>>0
M;;F"`&BY"``0X^#RX``$[`$[OR55PNK*8L'6[`$@.@56N1H`Y[D:`.;L:"*_
M/E6Y"`#@[&@"(1Y6[(X[OR55N>=@>>R.(#H%5KF"`'&SP0`8XS#RZ``$XX#R
M\``$PCK*8L'6PHK*8L'6N1H`/;D:`(FY&@`WL\T`D>QQ(K\^5;D(`#GL<0(A
M'E;L`SN_)56YYW#6[`,@.@56N8(`WN,0\O@`!+D:`(W"&LIBP=:Y"`"`N1H`
M%NQN(K\^5>QN`B$>5NSH.[\E5;GG8`?LZ"`Z!5:Y@@`#N1H`$+D(`![LT3N_
M)57LT2`Z!5;LXR*_/E7CD/,```3LXP(A'E;"FLIBP=:YY^`&N1H`E[F"``BY
M&@"0N0@`G>S9.[\E5>S9(#H%5N,P\P@`!+/!`"W".LIBP=;CT/,0``2Y&@`V
MPMK*8L'6[&@BOSY5N1H`WNQH`B$>5KGG8(ZSS0#BN8(`@;D:`#BY"``^[`,[
MOR55[`,@.@56[($BOSY5[.DBOSY5[($"(1Y6[.D"(1Y6N>>`=N,0\Q@`!+F"
M`'G"&LIBP=:Y&@#7N1H`%KGH`&VYY^`([)8@OP!5N><P<+D$`-[L!CN_)57C
MT"`@``BY&@`7P-H`````[`D`.@56X]`@(``DN0@`$.S3(K\^5>L)``(`#.S3
M`B$>5NP)`"$>5KGHL'VY@@#MP'H`````XW`@&``DN>=@OKD(``7C,/,@``3`
M"@````#C`"`0`"3".LIBP=;C8/"@``2Y"``T[$$@OP!5N1H`.+D(`&3L@3N_
M)57`:@````#C8"`(`"3LA``Z!5:Y!``3N1H`&[D(`!C`&@````#C$"```"35
M!_,HH"BG=``*ZV_S8``$!_ZY!`!-I_3T^<#E___A]@<'!P<'!^OO\'``)*<I
M`(#C\/]@_W'`Y?__X!C`,6=%(P'`#^_-JXGC,"```"3C`"`(`"3`3YBZW/[`
M41`R5';C0"`0`"3C4"`8`"3`/\/2X?#E2"`H``#C,"`@`"3E2"`P``#E3"!X
M``#K[_$0``0'_@<'!P?K;_`P`"3K%``#``VY!`"RXR`@*``$N0@`$NQ1(+\`
M5;D$`)3C\/]@_W'C0+`P``2Y!`"CN3$`(:?$``2G2P`!XU"P*``DZPD`'0`,
MN0@`!.,`L#``)./0L'@`$J=T`(E!<+`XIYX`/Z?$`*WL:?_``-B(8``&[.8`
M`0#8[!X?N095[%'_P`#90=&@`.N%``8`#*>+``'L2#Z_`%6GA``LIT\``:>$
M`!JG3P`"IX0`#-(_<`"@`+D$`"M!H*!`P.7___0-TC]P`*``N00`*T&@H$#`
MY?__]`/2/W``H`"Y!``K0:"@0,#E___S^;D@`*VGA``IZX@``@`,TC]P`*``
MN00`*\#E___SZKD$`"O2/W``H$#`Y?__\^*Y!``KTC]P`*"`P.7___/:N00`
M*](_<`"@P$&@H0#`Y?__\]"GA__>IYK_P(E@``8;EKD4`)FY!``]N00`)[D$
M`$G`Y?__XAI0D+!XZV_PT``$!_ZGB`!`&XT9B;D$`#JY\C")07"P.+D4`&BY
M!``GN00`1KD8`"W`Y?__X?\8.%HPL'A0,+!XISX`0*=T_^`;F+D(`*:Y%`"9
MN00`*\#E___SD*?T_U.Y!`#:I_3_Q0<'!P<'!^M_\#@`)+D$`+/C@#`H``3C
MD#`P``3L&#J_/55!,#`XN10`0;D$`**G&@`!052P.)*`4`"Y%``AN0@`,N/P
M_V#_<:<>`#BGQ`"CI^@`0+GY$"X9X:>$`&'L$O__`-BY!``CZT$`"`#>$D2G
MA`!1['3__P#8&%3L!#Z_`%6GA``IIPX``:>$`!FG#@`"IX0`"^,@-```-M?_
M,``P`!A'02`Q`.,@)```-M?_(``@`*=*__]!("$`XR`D```VU_\@`"``ITX`
M`4$@(0"GA``AZS4``@#>XR`D```VU_\@`"``XR`E```VU_\A`"$`XR`F```V
MU_\B`"(`XR`G```VU_\C`",`02`D`*<V_^:Y%@#AQN````"FN00`*\#E___R
M]]<WL#BP.+D$`"NG>0``['D`!V!5['D(#V!5['D0%V!5['D8'R!5[(<`'P!5
MXX"P<``DP.7___+;N00`*]("H`"P!-(`H`.P!](#H`2P#-(#H`BP%-(#H`RP
M'-(#H!"P).M_\-@`!,#T___@C:<(`#BY^1!P&0&GA/_([!?__P#8N00`(^MQ
M``@`WA)WIX0`4>SG__\`V!A7[`<^OP!5IX0`*:<.``&GA``9IPX``J>$``OC
M(#0``#;7_S``,``8?D$@,0#C("0``#;7_R``(`"G>O__02`A`.,@)```-M?_
M(``@`*=^``%!("$`IX0`(>LU``(`WN,@)```-M?_(``@`.,@)0``-M?_(0`A
M`.,@)@``-M?_(@`B`.,@)P``-M?_(P`C`$$@)`"G-O_FN18`0<9`````"*?T
M_V?7`"``(`#7`"``(`#$6```,+3`]/__W=D'!P<'ZV_P,``DN00`'Z?[_V#C
M$/```"3`P```+XH'!^-`\1``!.MO\-``!`?T!P<```````(``25S+R5S`"]P
M<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT
M97)N86QS.CI005(Z.D)/3U0``"]P<F]C+R5I+R5S`&5X90`N`%!!4E]414U0
M``!005)?4%)/1TY!344``#H`+P!015),-4Q)0@``4$523$Q)0@!015),-4]0
M5```4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,
M14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P``4$%2
M7T=,3T)!3%]435!$25(`4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!
M4E]'3$]"04Q?0TQ%04X``#$`;'-E96L@9F%I;&5D``!R96%D(&9A:6QE9`!,
M1%],24)205)97U!!5$@`4UE35$5-```E,#)X```E<R5S)7,E<P``<&%R+0``
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES
M('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R
M871I;VXI"@``4$%42```<&%R;```+G!A<@``<VAO<G0@<F5A9```)7,E<V-A
M8VAE+25S)7,``"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P``&`!P
M97)L```P`%!!4CHZ4&%C:V5R.CI615)324].```Q+C`U.0!5;F%B;&4@=&\@
M8W)E871E(&-A8VAE(&1I<F5C=&]R>0``)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M+64``"TM``!54T52``!54T523D%-10``5$5-4$1)4@!435``+W1M<```979A
M;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[
M(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R
M7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H
M95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<
M;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C
M:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T
M(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D
M8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M
M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU
M;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D
M8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S
M+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!
M4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)
M0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N
M:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA
M;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M2
M96UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF
M:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A
M<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F
M("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP
M*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.
M2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I
M;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D
M;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=
M.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE
M"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D
M9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF
M,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N
M9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*
M?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D
M("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H
M*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*
M<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL
M"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN
M*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-
M4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*
M;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?
M=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]4
M14U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I
M;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*
M=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H
M<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N
M)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-
M04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D[
M"FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G
M:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D[
M"FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET
M:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,
M15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&
M2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!
M0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M
M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA
M<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D
M1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F
M9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U
M=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O
M9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*
M;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]
M("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=
M*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@
M,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F
M:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@
M)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]
M('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M
M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L
M("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M
M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L
M93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U
M;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD
M24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D
M14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2![
M"FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T
M(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^
M<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@
M)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M
M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F
M:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H
M.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D
M=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S
M*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B
M)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*
M;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C
M:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET
M:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S
M=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S
M:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II
M("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R
M"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@
M)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5]
M(#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I
M;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@
M/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q
M(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@
M97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@
M>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@
M>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@
M)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG
M.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H
M)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;
M0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q
M("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@
M*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?
M5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2
M.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L
M($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&
M:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F
M:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I
M92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D
M9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP
M(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D
M>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I
M*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ
M+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@
M;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY
M("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO
M="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L
M;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE
M.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@
M9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I
M;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I
M;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D
M97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O
M(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13
M=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D
M97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z
M("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I
M<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R
M97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#
M;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP
M<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H
M($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E
M<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X
M="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L
M:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME
M>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@
M*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y
M?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*
M9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I
M<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL
M87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2![
M"FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@
M>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]
M"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET
M=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]
M?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG
M($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D
M9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E
M;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968[
M"F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@
M<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T
M:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\
M96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE
M*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M
M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M
M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H
M*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T
M96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54
M;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@
M*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]
M"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]
M($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C
M='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?
M;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP
M(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*
M)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F
M<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A
M73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E
M9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!
M4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@
M1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@
M07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF
M9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A
M:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I
M.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@
M(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J
M(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#
M86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N
M+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@
M8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z
M:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD[
M"FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N
M;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG
M.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A
M8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T
M9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D
M9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ
M92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@
M:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92![
M"F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?
M;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S
M=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%
M<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*
M8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]
M"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE
M(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=
M(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M
M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6
M*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I
M(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI
M.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T
M:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R
M"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E
M($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0[
M"G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&
M8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/
M.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z
M.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ
M4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R
M:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@
M5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@
M>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q
M=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER
M92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E
M<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A
M=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-
M4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN
M97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@
M)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED
M*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE
M9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ
M3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA
M;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!
M345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@
M/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N
M86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF
M("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*
M?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M
M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@
M)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H
M(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T
M:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D
M9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B
M7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B
M=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE
M7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C
M86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?
M0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE
M7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]
M("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S
M879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM
M>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D
M9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY
M("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN
M="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E
M;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F
M=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL
M;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[
M4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI
M+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H
M)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?
M5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@
M<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A
M)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?
M9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA
M;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S
M>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX[
M"GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%
M35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D
M<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E
M;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@
M/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G
M;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T[
M"FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P
M<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D
M(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H
M*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@
M8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_
M7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B![
M"FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N
M.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H
M<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I
M("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2
M(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[
M(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D
M7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?
M0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H
M)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT
M(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP
M=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD
M7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET
M96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA
M9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I
M;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L
M.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H
M(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O
M("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@
M)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?
M7T524D]2.PHQ.PI?7T5.1%]?"@```'!E<FQX<VDN8P``0T%#2$4`````````
M``$;`SL```#L````'/__@*@```7D__^#,````0C__X0H```!./__A0@```&8
M__^%F````<C__X<````"!/__B:````)$__^*D````H#__XL(```"O/__BT``
M``+0__^,&````PS__XP@```#(/__CH````-<__^.N````XC__Y`````#S/__
ME>````0`__^66```!##__Y;0```$7/__F-````24__^9````!+3__YH0```%
M%/__H*@```5D__^B\```!:#__Z/0```&*/__NH@```9H__^Z^```!HS__[S(
M```&S/__OS````<(`````````!0``````7I2``%X#@$;#`^@`0<.`````!0`
M```<__^"(````$(``````````````!0``````7I2``%X#@$;#`^@`0``````
M`%P````<__^"Z````-P`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[``@*8"L_.
MS<S+RLG(Q\8.H`%""UP*S\[-S,O*R<C'Q@Z@`4(+3@K/SLW,R\K)R,?&#J`!
M0@L``````"P```!\__^#:````(X`1HH*BPF,"(T'C@:/!48.V`,">@K/SLW,
MR\H.H`%""P```#@```"L__^#R````6(`1H8.APV(#(D+B@J+"8P(C0>.!H\%
M1@[@`W0*S\[-S,O*R<C'Q@Z@`4(+`````#P```#H__^$]````IP`1H8.APV(
M#(D+B@J+"8P(C0>.!H\%1@[8`@,!9`K/SLW,R\K)R,?&#J`!0@L````````X
M```!*/__AU0```#P`$:'#8@,B0N*"HL)C`B-!XX&CP5&#L@B`I0*S\[-S,O*
MR<C'#J`!0@L````````X```!9/__B`@```!T`%Z&#H<-B`R)"XH*BPF,"(T'
MC@:/!4P.R`("2,_.S<S+RLG(Q\8.H`$````````0```!H/__B$0````X````
M`````#@```&T__^(:````-0`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[80@*X
M"L_.S<S+RLG(Q\8.H`%""P```!````'P__^)!`````8`````````.````@3_
M_XCX```"7`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#O`C`G8*S\[-S,O*R<C'
MQ@Z@`4(+````*````D#__XL<````-@!*BPF,"(T'C@:/!48.P`)@S\[-S,L.
MH`$```````!````";/__BR@```%(`$:)"XH*BPF,"(T'C@:/!48.R"("Y`K/
MSLW,R\K)#J`!0@M<"L_.S<S+RLD.H`%&"P```````#````*P__^,+```!=P`
M1HH*BPF,"(T'C@:/!48.T`(#!9P*S\[-S,O*#J`!1@L````````L```"Y/__
MD=@```!X`$R+"8P(C0>.!H\%1@[0`@)6"L_.S<S+#J`!0@L````````H```#
M%/__DB````!X`%J&#H<-B`R)"XH*BPF,"(T'C@:/!48.Z`(``````#0```-`
M__^2;````@``3H@,B0N*"HL)C`B-!XX&CP5&#M""!`,!P`K/SLW,R\K)R`Z@
M`4(+````'````WC__Y0T````+@!&C@:/!48.P`)@S\X.H`$```!<```#F/__
ME$0```$*`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.X`("6@K/SLW,R\K)R,?&
M#J`!0@M:"L_.S<S+RLG(Q\8.H`%&"P)V"L_.S<S+RLG(Q\8.H`%&"P````!,
M```#^/__E/0```:8`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.D`4#`GH*S\[-
MS,O*R<C'Q@Z@`4(+`P+."L_.S<S+RLG(Q\8.H`%&"P```#@```1(__^;/```
M`D0`1H<-B`R)"XH*BPF,"(T'C@:/!5(.T`(#`;P*S\[-S,O*R<C'#J`!0@L`
M`````$````2$__^=2````-H`1HD+B@J+"8P(C0>.!H\%1@[0`@*2"L_.S<S+
MRLD.H`%""VX*S\[-S,O*R0Z@`48+````````0```!,C__WJ\```"B`!&A@Z'
M#8@,B0N*"HL)C`B-!XX&CP5&#N@"`P'$"L_.S<S+RLG(Q\8.H`%""P``````
M```````\```%#/__G:```!:R`$Z&#H<-B`R)"XH*BPF,"(T'C@:/!48.T`<#
M%HX*S\[-S,O*R<C'Q@Z@`4(+````````(```!4S__[08````;`!*C@:/!48.
MP`("6L_.#J`!````````/```!7#__[1D```!R@!,A@Z'#8@,B0N*"HL)C`B-
M!XX&CP5>#L`"`P%""L_.S<S+RLG(Q\8.H`%""P```````#@```6P__^U]```
M`F@`1H<-B`R)"XH*BPF,"(T'C@:/!7P.P`(#`40*S\[-S,O*R<C'#J`!1@L`
M`````!````7L__^X(`````P`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````CD````````"-(``````````$````````"S@``
M```````!`````````MX`````````#````````!CX``````````T```````!>
ML``````````9````````N\@`````````&P`````````(`````````!H`````
M``"[T``````````<``````````@`````;__^]0````````*0``````````4`
M```````,*``````````&`````````W``````````"@````````1.````````
M``L`````````&``````````5`````````````````````P```````+W8````
M``````(````````%$``````````4``````````<`````````%P```````!/H
M``````````<````````1D``````````(`````````E@`````````"0``````
M```8`````````!X`````````"`````!O___[``````@```$`````;____@``
M`````!$P`````&____\``````````0````!O___P````````$'8`````;___
M^0`````````.````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````"[V``````````````````````````````99@```````!F&````````
M&:8````````9Q@```````!GF````````&@8````````:)@```````!I&````
M````&F8````````:A@```````!JF````````&L8````````:Y@```````!L&
M````````&R8````````;1@```````!MF````````&X8````````;I@``````
M`!O&````````&^8````````<!@```````!PF````````'$8````````<9@``
M`````!R&````````'*8````````<Q@```````!SF````````'08````````=
M)@```````!U&````````'68````````=A@```````!VF````````'<8`````
M```=Y@```````!X&````````'B8````````>1@```````!YF````````'H8`
M```````>I@```````![&````````'N8````````?!@```````!\F````````
M'T8````````?9@```````!^&````````'Z8````````?Q@```````!_F````
M````(`8`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(!@``````````````````,`("E!!4BYP;0H`````````````
M`````&'@````````7SP``````````````````%_<````````7^````````!A
MU````````%]"````````8=P``````````````````&'$````````8<H`````
M`````````````&'F1T-#.B`H1&5B:6%N(#$S+C(N,"TR*2`Q,RXR+C```"YS
M:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM
M=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG
M;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`
M+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A
M<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O
M;6UE;G0`````````````````````````````````````````````````````
M``````````````````````````````````````L````!``````````(`````
M```".`````````(X``````````\````````````````````!````````````
M```3````!P`````````"`````````D@````````"2``````````D````````
M````````````!```````````````)@````<``````````@````````)L````
M`````FP`````````(`````````````````````0``````````````#1O___V
M``````````(````````"D`````````*0`````````-P````%````````````
M```(```````````````^````"P`````````"`````````W`````````#<```
M``````BX````!@````(`````````"``````````8````1@````,`````````
M`@````````PH````````#"@````````$3@````````````````````$`````
M`````````$YO____``````````(````````0=@```````!!V`````````+H`
M```%```````````````"``````````(```!;;____@`````````"````````
M$3`````````1,`````````!@````!@````$`````````"```````````````
M:@````0``````````@```````!&0````````$9`````````"6`````4`````
M``````````@`````````&````'0````$`````````$(````````3Z```````
M`!/H````````!1`````%````%0`````````(`````````!@```!^`````0``
M```````&````````&/@````````8^`````````!`````````````````````
M!```````````````>0````$`````````!@```````!DX````````&3@`````
M```&X`````````````````````0`````````(````(0````!``````````8`
M```````@&````````"`8````````/I@````````````````````(````````
M``````"*`````0`````````&````````7K````````!>L``````````L````
M````````````````!```````````````D`````$``````````@```````%[@
M````````7N````````!`D`````````````````````@``````````````)@`
M```!``````````(```````"?<````````)]P`````````.P`````````````
M```````$``````````````"F`````0`````````"````````H&````````"@
M8`````````8P````````````````````"```````````````L`````X`````
M`````P```````+O(````````J\@`````````"`````````````````````@`
M````````"````+P````/``````````,```````"[T````````*O0````````
M``@````````````````````(``````````@```#(````!@`````````#````
M````N]@```````"KV`````````(`````!@``````````````"``````````0
M````T0````$``````````P```````+W8````````K=@````````"*```````
M``````````````@`````````"````-8````!``````````,```````#`````
M`````+```````````(@````````````````````(``````````````#<````
M"``````````#````````P(@```````"PB``````````H````````````````
M````"```````````````X0````$`````````,```````````````````L(@`
M````````'@````````````````````$``````````0````$````#````````
M`````````````````````+"F`````````.H````````````````````!````
%````````
